<?php

namespace Jazzaaf\xenAntiVirus\XF\ControllerPlugin;

use XF\ControllerPlugin\AbstractPlugin;

class Attachment extends AbstractPlugin
{
	public function displayAttachment(\XF\Entity\Attachment $attachment, $allowViewLog = true)
	{
		$options = \XF::options();

		if ($options->jz_xenAntiVirus_disable_attachments && $options->jz_xenAntiVirus_api_key && $attachment->Data->AttachmentCheck) {
		
			if ($attachment->Data->AttachmentCheck->check_status != 'clean' && $attachment->Data->AttachmentCheck->check_status != '') 
			{
				return $this->error(\XF::phrase('attachment_still_not_cleared_for_downloading'));
			}
		}

		
		if (!$attachment->Data || !$attachment->Data->isDataAvailable())
		{
			return $this->error(\XF::phrase('attachment_cannot_be_shown_at_this_time'));
		}

		$this->setResponseType('raw');

		$eTag = $this->request->getServer('HTTP_IF_NONE_MATCH');
		if ($eTag && $eTag == '"' . $attachment['attach_date'] . '"')
		{
			$return304 = true;
		}
		else
		{
			if (!$attachment->temp_hash && $allowViewLog)
			{
				// if not associated, don't log it
				$this->getAttachmentRepo()->logAttachmentView($attachment);
			}

			$return304 = false;
		}

		$viewParams = [
			'attachment' => $attachment,
			'return304' => $return304
		];
		return $this->view('XF:Attachment\View', '', $viewParams);
	}	
	
	/**
	 * @return \XF\Repository\Attachment
	 */
	protected function getAttachmentRepo()
	{
		return $this->repository('XF:Attachment');
	}
}